@@ -6,7 +6,7 @@ eval { require warnings; }; #it's ok if we can't load warnings
 use FileHandle;
 
 use vars qw( $VERSION );
-$VERSION = '0.09';
+$VERSION = '0.10';
 
 =head1 NAME
 
@@ -119,16 +119,16 @@ Returns a reference to a hash containing;
 (for example, a file marked up for use in Audio::Mix)
 
     {
-	'keywords'	=> 'bpm:126 key:a',
-	'name'		=> 'Mission Venice',
-	'artist'	=> 'Nightmares on Wax'
+        'keywords' => 'bpm:126 key:a',
+        'name'     => 'Mission Venice',
+        'artist'   => 'Nightmares on Wax'
     };
 
 =cut
 
 sub get_info {
     my $self = shift;
-    return unless exists( $self -> {'data'} -> {'info'} );
+    return unless exists $self -> {'data'} -> {'info'};
     return $self -> {'data'} -> {'info'};
 }
 
@@ -173,7 +173,7 @@ Returns a reference to a hash containing;
 
 sub get_cues {
     my $self = shift;
-    return unless exists( $self -> {'data'} -> {'cue'} );
+    return unless exists $self -> {'data'} -> {'cue'};
     my $data = $self -> {'data'};
     my $cues = $data -> {'cue'};
     my $output = {};
@@ -225,8 +225,8 @@ sub _read_raw {
     my $len = shift;
     my $data;
     return unless $len && $len > 0;
-    $self -> {'pos'} += read( $self -> {'handle'}, $data, $len );
-    return $data;
+    $self -> {'pos'} += read $self -> {'handle'}, $data, $len;
+    return $data; 
 }
 
 =head2 read
@@ -245,7 +245,7 @@ The numbers will be in the range;
 =cut
 
 # read is generated by _init_read_sub
-sub read { die "call _init_read_sub first"; };
+sub read { die "ERROR: can't call read without first calling _init_read_sub"; };
 
 sub _init_read_sub {
     my $self = shift;
@@ -384,7 +384,7 @@ Moves the current audio data position to sample offset.
 sub move_to_sample {
     my $self = shift;
     my $pos = shift;
-    return $self -> move_to() unless defined( $pos );
+    return $self -> move_to() unless defined $pos ;
     return $self -> move_to( $pos * $self -> {'data'} -> {'block_align'} );
 }
 
@@ -494,15 +494,15 @@ sub _read_file {
             # rectify cooledit 96 data-chunk bug
             $head = $walkover . $self -> _read_raw( 3 );
             $walkover = undef;
-            print( "debug: CoolEdit 96 data-chunk bug detected!\n" ) if $debug;
+            print "debug: CoolEdit 96 data-chunk bug detected!\n" if $debug;
         } else {
             $head = $self -> _read_raw( 4 );
         }
         my $chunk_len = $self -> _read_long();
-        printf( "debug: head: '$head' at %6d (%6d bytes)\n", $self->{pos}, $chunk_len ) if $debug;
+        printf "debug: head: '$head' at %6d (%6d bytes)\n", $self->{pos}, $chunk_len if $debug;
         if ( $head eq 'fmt ' ) {
             my $format = $self -> _read_fmt( $chunk_len );
-            my $comp = delete( $format -> {'format'} );
+            my $comp = delete $format -> {'format'};
             if ( $comp == 65534 ) {
                 $format -> {'wave-ex'} = 1;
             } elsif ( $comp != 1 ) {
@@ -574,7 +574,7 @@ sub _read_list {
     my $pos = 4;
 
     if ( $note eq 'adtl' ) {
-        my %allowed = map { $_, 1 } qw( ltxt note labl );
+        my %allowed = map { $_ => 1 } qw( ltxt note labl );
         while ( $pos < $length ) {
             my $head = $self -> _read_raw( 4 );
             $pos += 4;
@@ -636,7 +636,7 @@ sub _read_cue {
     my $output;
     for ( 1 .. $cues ) {
         my $record = $self -> _decode_block( \@fields, \@plain );
-        my $id = delete( $record -> {'id'} );
+        my $id = delete $record -> {'id'};
         $output -> {$id} = $record;
     }
     return $output; 
@@ -699,7 +699,7 @@ sub _decode_block {
             }
         }
     }
-    my $no_fields = scalar( @{$fields} );
+    my $no_fields = scalar @{$fields};
     my %record;
     for my $id ( 0 .. $#{$fields} ) {
         if ( exists $plain{$id} ) {
@@ -721,7 +721,7 @@ sub _read_fmt {
     foreach my $type ( @{$fields} ) {
         $pack_str .= $types -> {'types'} -> {$type};
     }
-    my @data = unpack( $pack_str, $data );
+    my @data = unpack $pack_str, $data;
     my %record;
     for my $id ( 0 .. $#{$fields} ) {
         $record{ $fields -> [$id] } = $data[$id];
@@ -732,7 +732,7 @@ sub _read_fmt {
 sub _read_long {
     my $self = shift;
     my $data = $self -> _read_raw( 4 );
-    return unpack( 'V', $data );
+    return unpack 'V', $data; 
 }
 
 sub _error {
@@ -743,7 +743,7 @@ sub _error {
 =head1 AUTHORS
 
     Nick Peskett (see http://www.peskett.co.uk/ for contact details).
-    Brian Szymanski <ski-cpan@allafrica.com> (0.07-0.09)
+    Brian Szymanski <ski-cpan@allafrica.com> (0.07-0.10)
     Wolfram humann (pureperl 24 and 32 bit read support in 0.09)
     Kurt George Gjerde <kurt.gjerde@media.uib.no>. (0.02-0.03)
 
